@@ -266,13 +266,7 @@ def generate_subtitles(  # pylint: disable=too-many-locals,too-many-arguments
     Given an input audio/video file, generate subtitles in the specified language and format.
     """
 
-    if os.name != "nt" and "Darwin" in os.uname():
-        # the default unix fork method does not work on Mac OS
-        # need to use forkserver
-        start_method = multiprocessing.get_start_method(allow_none=True)
-        if 'forkserver' != start_method:
-            # multiprocessing.set_start_method('forkserver')
-            multiprocessing.set_start_method('spawn')
+
 
     audio_filename, audio_rate = extract_audio(source_path)
 
@@ -432,6 +426,14 @@ def main():
     if not validate(args):
         return 1
 
+    if os.name != "nt" and "Darwin" in os.uname():
+        # the default unix fork method does not work on Mac OS
+        # need to use forkserver
+        start_method = multiprocessing.get_start_method(allow_none=True)
+        if 'forkserver' != start_method:
+            # multiprocessing.set_start_method('forkserver')
+            multiprocessing.set_start_method('spawn')
+
     file_queue = set()
 
     input_is_dir = os.path.isdir(args.source_path)
@@ -451,7 +453,7 @@ def main():
     # file_queue = [random.choice(list(file_queue))]
 
     try:
-        print(file_queue)
+        # print(file_queue)
         for item in file_queue:
             try:
                 pass
